summaryrefslogtreecommitdiffstats
path: root/kcontrol/kcontrol/proxywidget.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:46:05 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:46:05 -0600
commit73c08b592db45af554b9f21029bc549d70f683ab (patch)
tree122898ea951e59fdc4419b3c84b7a6c2dd0bb5f7 /kcontrol/kcontrol/proxywidget.cpp
parente81bdee8ae92d6eeb82daa8c0a0e46bf37f4a6da (diff)
downloadtdebase-73c08b592db45af554b9f21029bc549d70f683ab.tar.gz
tdebase-73c08b592db45af554b9f21029bc549d70f683ab.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'kcontrol/kcontrol/proxywidget.cpp')
-rw-r--r--kcontrol/kcontrol/proxywidget.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kcontrol/kcontrol/proxywidget.cpp b/kcontrol/kcontrol/proxywidget.cpp
index dde14168b..e726c7c56 100644
--- a/kcontrol/kcontrol/proxywidget.cpp
+++ b/kcontrol/kcontrol/proxywidget.cpp
@@ -20,7 +20,7 @@
#include <unistd.h> // for getuid()
#include <kpushbutton.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <klocale.h>
#include <kapplication.h>
#include <kcmodule.h>
@@ -120,7 +120,7 @@ public:
~ProxyContentWidget(){}
// this should be really done by qscrollview in AutoOneFit mode!
- TQSize tqsizeHint() const { return tqminimumSizeHint(); }
+ TQSize sizeHint() const { return minimumSizeHint(); }
};
@@ -144,7 +144,7 @@ ProxyView::ProxyView(KCModule *_client, const TQString&, TQWidget *parent, bool
}
client->reparent(contentWidget,0,TQPoint(0,0),true);
vbox->addWidget( client );
- vbox->activate(); // make sure we have a proper tqminimumSizeHint
+ vbox->activate(); // make sure we have a proper minimumSizeHint
addChild(contentWidget);
}